@@ -3,10 +3,10 @@ Copyright (c) by respective owners including Yahoo!, Microsoft, and
 individual contributors. All rights reserved.  Released under a BSD
 license as described in the file LICENSE.
  */
-#ifndef CACHE_H
-#define CACHE_H
-
-#include "parse_example.h"
+#pragma once
+#include "v_array.h"
+#include "io_buf.h"
+#include "example.h"
 
 const size_t int_size = 6;
 const size_t char_size = 2;
@@ -20,4 +20,3 @@ void cache_features(io_buf& cache, example* ae, uint32_t mask);
 void output_byte(io_buf& cache, unsigned char s);
 void output_features(io_buf& cache, unsigned char index, feature* begin, feature* end, uint32_t mask);
 
-#endif
