@@ -3,7 +3,4 @@ Copyright (c) by respective owners including Yahoo!, Microsoft, and
 individual contributors. All rights reserved.  Released under a BSD
 license as described in the file LICENSE.
 */
-
-namespace NOOP {
-  learner setup(vw&);
-}
+LEARNER::base_learner* noop_setup(vw& all);
