@@ -1,3 +1,5 @@
+#pragma once
 void msrand48(uint64_t initial);
 float merand48(uint64_t& initial);
 float frand48();
+float frand48_noadvance();
