@@ -3,6 +3,4 @@ Copyright (c) by respective owners including Yahoo!, Microsoft, and
 individual contributors. All rights reserved.  Released under a BSD
 license as described in the file LICENSE.
  */
-namespace SENDER{
-  learner setup(vw& all, po::variables_map& vm, vector<string> pairs);
-}
+LEARNER::base_learner* sender_setup(vw& all);
